@@ -3,5 +3,5 @@ from .is_authenticated import IsAuthenticated, IsUserAuthenticated
 from .is_staff import IsStaff, IsUserStaff
 from .has_permission import HasPermission, HasUserPermission
 from .is_member import IsMember, IsUserMember
-# from .token import TamarinTokenSerializer, TamarinTokenObtainPairView, TamarinRefreshView
-# from rest_framework_simplejwt.tokens import AccessToken
+from .token import TamarinTokenSerializer, TamarinTokenObtainPairView, TamarinRefreshView
+from rest_framework_simplejwt.tokens import AccessToken
